==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebMaskInputBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { WebInputBaseDescription } from "./WebInputBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebMaskInputBaseDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebMaskInputBaseDescription, _super);
    function WebMaskInputBaseDescription() {
        var _this = _super.call(this) || this;
        _this.ae = null;
        _this.ac = false;
        return _this;
    }
    WebMaskInputBaseDescription.prototype.get_type = function () {
        return "WebMaskInputBase";
    };
    Object.defineProperty(WebMaskInputBaseDescription.prototype, "prompt", {
        get: function () {
            return this.ae;
        },
        set: function (a) {
            this.ae = a;
            this.e("Prompt");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebMaskInputBaseDescription.prototype, "invalid", {
        get: function () {
            return this.ac;
        },
        set: function (a) {
            this.ac = a;
            this.e("Invalid");
        },
        enumerable: true,
        configurable: true
    });
    WebMaskInputBaseDescription.$t = markType(WebMaskInputBaseDescription, 'WebMaskInputBaseDescription', WebInputBaseDescription.$);
    return WebMaskInputBaseDescription;
}(WebInputBaseDescription));
export { WebMaskInputBaseDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebMaskInputBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebInputBaseDescription } from "./WebInputBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebMaskInputBaseDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebMaskInputBaseDescription, _super);
    function WebMaskInputBaseDescription() {
        var _this = _super.call(this) || this;
        _this.ag = null;
        return _this;
    }
    WebMaskInputBaseDescription.prototype.get_type = function () {
        return "WebMaskInputBase";
    };
    Object.defineProperty(WebMaskInputBaseDescription.prototype, "prompt", {
        get: function () {
            return this.ag;
        },
        set: function (a) {
            this.ag = a;
            this.g("Prompt");
        },
        enumerable: false,
        configurable: true
    });
    WebMaskInputBaseDescription.$t = markType(WebMaskInputBaseDescription, 'WebMaskInputBaseDescription', WebInputBaseDescription.$);
    return WebMaskInputBaseDescription;
}(WebInputBaseDescription));
export { WebMaskInputBaseDescription };
